/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.cs.service;

import se.vgregion.portal.cs.domain.SiteKey;
import se.vgregion.portal.cs.domain.UserSiteCredential;

import java.util.Collection;

/**
 * Service interface for Credential Store.
 *
 * @author <a href="mailto:david.rosell@redpill-linpro.com">David Rosell</a>
 */
public interface CredentialService {

    /**
     * Retrive user credentials. If no credentals are stored, null will be returned.
     * 
     * @param uid
     *            - user identifier.
     * @param siteKey
     *            - site credental identifier.
     * @return credentials
     */
    UserSiteCredential getUserSiteCredential(String uid, String siteKey);

    UserSiteCredential getUserSiteCredential(Long siteCredentialId);

    Collection<UserSiteCredential> getAllSiteCredentials(String uid);

    Collection<SiteKey> getAllSiteKeys();

    SiteKey getSiteKey(Long siteKeyId);

    SiteKey getSiteKey(String siteKey);

    /**
     * Store a credental. Password will be encrypted before storage.
     * 
     * @param siteCredential
     *            - credental to be stored
     */
    void save(UserSiteCredential siteCredential);

    void save(SiteKey siteKey);

    void removeUserSiteCredential(Long siteCredentialId);

    void removeSiteKey(Long siteKeyId);
}
